==> linshare-core-1.7.9-src.tar.bz2: src/main/java/org/linagora/linshare/core/facade/webservice/admin/impl/LDAPConnectionFacadeImpl.java <==
/*
 * LinShare is an open source filesharing software, part of the LinPKI software
 * suite, developed by Linagora.
 * 
 * Copyright (C) 2015 LINAGORA
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version, provided you comply with the Additional Terms applicable for
 * LinShare software by Linagora pursuant to Section 7 of the GNU Affero General
 * Public License, subsections (b), (c), and (e), pursuant to which you must
 * notably (i) retain the display of the “LinShare™” trademark/logo at the top
 * of the interface window, the display of the “You are using the Open Source
 * and free version of LinShare™, powered by Linagora © 2009–2015. Contribute to
 * Linshare R&D by subscribing to an Enterprise offer!” infobox and in the
 * e-mails sent with the Program, (ii) retain all hypertext links between
 * LinShare and linshare.org, between linagora.com and Linagora, and (iii)
 * refrain from infringing Linagora intellectual property rights over its
 * trademarks and commercial brands. Other Additional Terms apply, see
 * <http://www.linagora.com/licenses/> for more details.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License and
 * its applicable Additional Terms for LinShare along with this program. If not,
 * see <http://www.gnu.org/licenses/> for the GNU Affero General Public License
 * version 3 and <http://www.linagora.com/licenses/> for the Additional Terms
 * applicable to LinShare software.
 */
package org.linagora.linshare.core.facade.webservice.admin.impl;

import java.util.HashSet;
import java.util.List;
import java.util.Set;

import org.apache.commons.lang.Validate;
import org.linagora.linshare.core.domain.constants.Role;
import org.linagora.linshare.core.domain.entities.LDAPConnection;
import org.linagora.linshare.core.exception.BusinessException;
import org.linagora.linshare.core.facade.webservice.admin.LDAPConnectionFacade;
import org.linagora.linshare.core.service.AccountService;
import org.linagora.linshare.core.service.UserProviderService;
import org.linagora.linshare.webservice.dto.LDAPConnectionDto;

public class LDAPConnectionFacadeImpl extends AdminGenericFacadeImpl implements LDAPConnectionFacade {

	private final UserProviderService userProviderService;

	public LDAPConnectionFacadeImpl(final AccountService accountService, final UserProviderService userProviderService) {
		super(accountService);
		this.userProviderService = userProviderService;
	}

	@Override
	public Set<LDAPConnectionDto> findAll() throws BusinessException {
		checkAuthentication(Role.SUPERADMIN);
		Set<LDAPConnectionDto> ldapConnectionsDto = new HashSet<LDAPConnectionDto>();
		List<LDAPConnection> ldapConnections = userProviderService.findAllLDAPConnections();
		for (LDAPConnection ldapConnection : ldapConnections) {
			ldapConnectionsDto.add(new LDAPConnectionDto(ldapConnection));
		}
		return ldapConnectionsDto;
	}

	@Override
	public LDAPConnectionDto find(String id) throws BusinessException {
		checkAuthentication(Role.SUPERADMIN);
		Validate.notEmpty(id, "ldap connection id must be set.");
		return new LDAPConnectionDto(userProviderService.findLDAPConnection(id));
	}

	@Override
	public LDAPConnectionDto update(LDAPConnectionDto ldapConnectionDto) throws BusinessException {
		checkAuthentication(Role.SUPERADMIN);
		return new LDAPConnectionDto(userProviderService.updateLDAPConnection(new LDAPConnection(ldapConnectionDto)));
	}

	@Override
	public LDAPConnectionDto create(LDAPConnectionDto ldapConnectionDto) throws BusinessException {
		checkAuthentication(Role.SUPERADMIN);
		return new LDAPConnectionDto(userProviderService.createLDAPConnection(new LDAPConnection(ldapConnectionDto)));
	}

	@Override
	public void delete(LDAPConnectionDto ldapConnectionDto) throws BusinessException {
		checkAuthentication(Role.SUPERADMIN);
		userProviderService.deleteConnection(ldapConnectionDto.getIdentifier());
	}
}

==> linshare-core-1.8.0-src.tar.bz2: src/main/java/org/linagora/linshare/core/facade/webservice/admin/impl/LDAPConnectionFacadeImpl.java <==
/*
 * LinShare is an open source filesharing software, part of the LinPKI software
 * suite, developed by Linagora.
 * 
 * Copyright (C) 2014 LINAGORA
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version, provided you comply with the Additional Terms applicable for
 * LinShare software by Linagora pursuant to Section 7 of the GNU Affero General
 * Public License, subsections (b), (c), and (e), pursuant to which you must
 * notably (i) retain the display of the “LinShare™” trademark/logo at the top
 * of the interface window, the display of the “You are using the Open Source
 * and free version of LinShare™, powered by Linagora © 2009–2014. Contribute to
 * Linshare R&D by subscribing to an Enterprise offer!” infobox and in the
 * e-mails sent with the Program, (ii) retain all hypertext links between
 * LinShare and linshare.org, between linagora.com and Linagora, and (iii)
 * refrain from infringing Linagora intellectual property rights over its
 * trademarks and commercial brands. Other Additional Terms apply, see
 * <http://www.linagora.com/licenses/> for more details.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License and
 * its applicable Additional Terms for LinShare along with this program. If not,
 * see <http://www.gnu.org/licenses/> for the GNU Affero General Public License
 * version 3 and <http://www.linagora.com/licenses/> for the Additional Terms
 * applicable to LinShare software.
 */
package org.linagora.linshare.core.facade.webservice.admin.impl;

import java.util.HashSet;
import java.util.List;
import java.util.Set;

import org.apache.commons.lang.Validate;
import org.linagora.linshare.core.domain.constants.Role;
import org.linagora.linshare.core.domain.entities.LDAPConnection;
import org.linagora.linshare.core.exception.BusinessException;
import org.linagora.linshare.core.facade.webservice.admin.LDAPConnectionFacade;
import org.linagora.linshare.core.facade.webservice.admin.dto.LDAPConnectionDto;
import org.linagora.linshare.core.service.AccountService;
import org.linagora.linshare.core.service.UserProviderService;

public class LDAPConnectionFacadeImpl extends AdminGenericFacadeImpl implements LDAPConnectionFacade {

	private final UserProviderService userProviderService;

	public LDAPConnectionFacadeImpl(final AccountService accountService, final UserProviderService userProviderService) {
		super(accountService);
		this.userProviderService = userProviderService;
	}

	@Override
	public Set<LDAPConnectionDto> findAll() throws BusinessException {
		checkAuthentication(Role.SUPERADMIN);
		Set<LDAPConnectionDto> ldapConnectionsDto = new HashSet<LDAPConnectionDto>();
		List<LDAPConnection> ldapConnections = userProviderService.findAllLDAPConnections();
		for (LDAPConnection ldapConnection : ldapConnections) {
			ldapConnectionsDto.add(new LDAPConnectionDto(ldapConnection));
		}
		return ldapConnectionsDto;
	}

	@Override
	public LDAPConnectionDto find(String id) throws BusinessException {
		checkAuthentication(Role.SUPERADMIN);
		Validate.notEmpty(id, "ldap connection id must be set.");
		return new LDAPConnectionDto(userProviderService.findLDAPConnection(id));
	}

	@Override
	public LDAPConnectionDto update(LDAPConnectionDto ldapConnectionDto) throws BusinessException {
		checkAuthentication(Role.SUPERADMIN);
		return new LDAPConnectionDto(userProviderService.updateLDAPConnection(new LDAPConnection(ldapConnectionDto)));
	}

	@Override
	public LDAPConnectionDto create(LDAPConnectionDto ldapConnectionDto) throws BusinessException {
		checkAuthentication(Role.SUPERADMIN);
		return new LDAPConnectionDto(userProviderService.createLDAPConnection(new LDAPConnection(ldapConnectionDto)));
	}

	@Override
	public void delete(LDAPConnectionDto ldapConnectionDto) throws BusinessException {
		checkAuthentication(Role.SUPERADMIN);
		userProviderService.deleteConnection(ldapConnectionDto.getIdentifier());
	}
}
